basic_dropdown_button library

Classes

BasicDropDownButton
A basic implementation of a drop-down button that handles internal state and displays the overlay menu.
CustomDropDownButton<T>
A customizable drop-down button widget that displays a menu with configurable styling, positioning, and behavior.
CustomDropDownButtonItem<T>
Represents an item in the CustomDropDownButton menu.

Enums

Enum representing the possible positions of the drop-down menu relative to the button.