AppDropDownTextField<T> class
A drop-down field that combines a TextField with a BasicDropDownButton.
This widget supports all standard TextField parameters and passes through menu-related parameters to the underlying BasicDropDownButton.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AppDropDownTextField
Constructors
-
AppDropDownTextField({required String itemText(T value), Key? key, TextEditingController? controller, FocusNode? focusNode, InputDecoration? decoration({required bool showMenu})?, TextInputType? keyboardType, TextInputAction? textInputAction, TextCapitalization textCapitalization = TextCapitalization.none, TextStyle? style, StrutStyle? strutStyle, TextAlign textAlign = TextAlign.start, TextAlignVertical? textAlignVertical, TextDirection? textDirection, bool readOnly = false, bool? showCursor, bool autofocus = false, String obscuringCharacter = '•', bool obscureText = false, bool autocorrect = true, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool enableSuggestions = true, int? maxLines = 1, int? minLines, bool expands = false, int? maxLength, MaxLengthEnforcement? maxLengthEnforcement, ValueChanged<
String> ? onChanged, VoidCallback? onEditingComplete, ValueChanged<String> ? onSubmitted, AppPrivateCommandCallback? onAppPrivateCommand, List<TextInputFormatter> ? inputFormatters, bool? enabled, double cursorWidth = 2, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, BoxHeightStyle selectionHeightStyle = ui.BoxHeightStyle.tight, BoxWidthStyle selectionWidthStyle = ui.BoxWidthStyle.tight, Brightness? keyboardAppearance, EdgeInsets scrollPadding = const EdgeInsets.all(20), DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, GestureTapCallback? onTap, void onTapOutside({required bool showMenu})?, MouseCursor? mouseCursor, InputCounterWidgetBuilder? buildCounter, ScrollController? scrollController, ScrollPhysics? scrollPhysics, Iterable<String> ? autofillHints, Clip clipBehavior = Clip.hardEdge, String? restorationId, bool enableIMEPersonalizedLearning = true, EditableTextContextMenuBuilder? contextMenuBuilder, SpellCheckConfiguration? spellCheckConfiguration, TextMagnifierConfiguration? magnifierConfiguration, UndoHistoryController? undoController, bool canRequestFocus = true, ContentInsertionConfiguration? contentInsertionConfiguration, bool? cursorOpacityAnimates, DropDownButtonPosition position = DropDownButtonPosition.bottomCenter, String? initValue()?, Widget customField({required Widget contextMenuBuilder(BuildContext, EditableTextState)?, required TextEditingController controller, required FocusNode focusNode, required String groupId, required void onTapOutside({required bool showMenu})?, required VoidCallback showHideMenuEvent, required bool showMenu})?, void onMenuChanged({required bool showMenu})?, Widget suffixIcon({required bool showMenu})?, T? selectItem}) -
const
Properties
- autocorrect → bool
-
final
-
autofillHints
→ Iterable<
String> ? -
final
- autofocus → bool
-
final
- buildCounter → InputCounterWidgetBuilder?
-
final
- canRequestFocus → bool
-
final
- clipBehavior → Clip
-
final
- contentInsertionConfiguration → ContentInsertionConfiguration?
-
final
- contextMenuBuilder → EditableTextContextMenuBuilder?
-
final
- controller → TextEditingController?
-
final
- cursorColor → Color?
-
final
- cursorHeight → double?
-
final
- cursorOpacityAnimates → bool?
-
final
- cursorRadius → Radius?
-
final
- cursorWidth → double
-
final
- customField → Widget Function({required Widget contextMenuBuilder(BuildContext, EditableTextState)?, required TextEditingController controller, required FocusNode focusNode, required String groupId, required void onTapOutside({required bool showMenu})?, required VoidCallback showHideMenuEvent, required bool showMenu})?
-
final
- decoration → InputDecoration? Function({required bool showMenu})?
-
final
- dragStartBehavior → DragStartBehavior
-
final
- enabled → bool?
-
final
- enableIMEPersonalizedLearning → bool
-
final
- enableInteractiveSelection → bool?
-
final
- enableSuggestions → bool
-
final
- expands → bool
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initValue → String? Function()?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- itemText → String Function(T value)
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardAppearance → Brightness?
-
final
- keyboardType → TextInputType?
-
final
- magnifierConfiguration → TextMagnifierConfiguration?
-
final
- maxLength → int?
-
final
- maxLengthEnforcement → MaxLengthEnforcement?
-
final
- maxLines → int?
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
- minLines → int?
-
final
- mouseCursor → MouseCursor?
-
final
- obscureText → bool
-
final
- obscuringCharacter → String
-
final
- onAppPrivateCommand → AppPrivateCommandCallback?
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
- onEditingComplete → VoidCallback?
-
final
- onMenuChanged → void Function({required bool showMenu})?
-
final
-
onSubmitted
→ ValueChanged<
String> ? -
final
- onTap → GestureTapCallback?
-
final
- onTapOutside → void Function({required bool showMenu})?
-
final
- position → DropDownButtonPosition
-
final
- readOnly → bool
-
final
- restorationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
final
- scrollPadding → EdgeInsets
-
final
- scrollPhysics → ScrollPhysics?
-
final
- selectionControls → TextSelectionControls?
-
final
- selectionHeightStyle → BoxHeightStyle
-
final
- selectionWidthStyle → BoxWidthStyle
-
final
- selectItem → T?
-
final
- showCursor → bool?
-
final
- smartDashesType → SmartDashesType?
-
final
- smartQuotesType → SmartQuotesType?
-
final
- spellCheckConfiguration → SpellCheckConfiguration?
-
final
- strutStyle → StrutStyle?
-
final
- style → TextStyle?
-
final
- suffixIcon → Widget Function({required bool showMenu})?
-
final
- textAlign → TextAlign
-
final
- textAlignVertical → TextAlignVertical?
-
final
- textCapitalization → TextCapitalization
-
final
- textDirection → TextDirection?
-
final
- textInputAction → TextInputAction?
-
final
- undoController → UndoHistoryController?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AppDropDownTextField< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited